package main

import (
	"pkg.deepin.io/lib/dbusutil"
	"pkg.deepin.io/lib/log"

	"pkg.deepin.io/dde/authentication/service/authenticate"
	"pkg.deepin.io/dde/authentication/service/fingerprint"
)

const (
	dbusServiceName = "com.deepin.daemon.Authenticate"
)

var logger = log.NewLogger("daemon/deepin-authenticate")

func main() {
	service, err := dbusutil.NewSystemService()
	if err != nil {
		logger.Fatal("failed to call NewSystemService. error:", err)
	}

	hasOwner, err := service.NameHasOwner(dbusServiceName)
	if err != nil {
		logger.Fatal("failed to call NameHasOwner. error:", err)
	}

	if hasOwner {
		logger.Fatalf("name %q already has the owner", dbusServiceName)
	}

	err = authenticate.Setup(service)
	if err != nil {
		logger.Warning("failed to setup Authenticate Service. error:", err)
	}

	err = fingerprint.Setup(service)
	if err != nil {
		logger.Warning("failed to setup Authenticate Service. error:", err)
	}

	err = service.RequestName(dbusServiceName)
	if err != nil {
		logger.Fatal("failed to call RequestName, name:", dbusServiceName, "err: ", err)
	}

	service.Wait()
}
