package authenticate

import "fmt"

type AuthResult interface {
	StatusCode() int
	String() string
	getType() string
	setType(type0 string)
}

type baseAuthResult struct {
	type0 string
}

func (b baseAuthResult) getType() string {
	return b.type0
}

func (b *baseAuthResult) setType(type0 string) {
	b.type0 = type0
}

type AuthResultSuccess struct {
	baseAuthResult
}

func (a AuthResultSuccess) StatusCode() int {
	return StatusCodeSuccess
}

func (a AuthResultSuccess) String() string {
	return joinTypeResult(a.type0, "success")
}

func joinTypeResult(type0, result string) string {
	if type0 == "" {
		return "<" + result + ">"
	}
	return fmt.Sprintf("<%s %s>", type0, result)
}

type AuthResultFailure struct {
	baseAuthResult
}

func (a AuthResultFailure) StatusCode() int {
	return StatusCodeFailure
}

func (a AuthResultFailure) String() string {
	return joinTypeResult(a.type0, "failure")
}

type AuthResultTimeout struct {
	baseAuthResult
}

func (a AuthResultTimeout) StatusCode() int {
	return StatusCodeTimeout
}

func (a AuthResultTimeout) String() string {
	return joinTypeResult(a.type0, "timeout")
}

type AuthResultError struct {
	baseAuthResult
	err error
}

func (a AuthResultError) StatusCode() int {
	return StatusCodeError
}

func (a AuthResultError) String() string {
	return joinTypeResult(a.type0, fmt.Sprintf("error(%s)", a.err))
}
