package authenticate

import (
	"fmt"
	"sync"
)

type Tx interface {
	init(parent *Group)
	authenticate() error
	setPassword(password string)
	end()
	getResult() AuthResult
	getType() string
}

type TxResultFn func(type0 string, result bool)

type baseTx struct {
	mu     sync.Mutex
	type0  string
	parent *Group
	result AuthResult
}

func (bt *baseTx) init(parent *Group) {
	bt.parent = parent
}

func (bt *baseTx) username() string {
	return bt.parent.username
}

func (bt *baseTx) getType() string {
	return bt.type0
}

func (bt *baseTx) giveResult(tx Tx, result AuthResult) {
	if result != nil {
		result.setType(tx.getType())
	}
	logger.Debugf("%v give result %v", tx, result)
	bt.setResult(result)

	if bt.parent.isEnded() {
		logger.Debug(bt, "ignore result")
	} else {
		bt.parent.resultCh <- tx
	}
}

func (bt *baseTx) getResult() AuthResult {
	bt.mu.Lock()
	defer bt.mu.Unlock()
	return bt.result
}

func (bt *baseTx) setResult(result AuthResult) {
	bt.mu.Lock()
	bt.result = result
	bt.mu.Unlock()
}

func (bt *baseTx) String() string {
	return fmt.Sprintf("<tx %s g=%s>", bt.getType(), bt.parent.id)
}
